#
# spec file for package libevdev
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum	2
Name:           libevdev
Version:        1.13.3
Release:        1.2
Summary:        A wrapper library for evdev devices
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://www.freedesktop.org/wiki/Software/libevdev/
Source0:        https://www.freedesktop.org/software/%{name}/%{name}-%{version}.tar.xz
Source1:        https://www.freedesktop.org/software/%{name}/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
Source3:        baselibs.conf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-base

%description
Library for handling evdev kernel devices. It abstracts the ioctls
through type-safe interfaces and provides functions to change
the appearance of the device.

%package devel
Summary:        Development files for libevdev library
Group:          Development/Libraries/C and C++
Requires:       libevdev%{sonum} = %{version}

%description devel
Library for handling evdev kernel devices. It abstracts the ioctls
through type-safe interfaces and provides functions to change
the appearance of the device.

Development files for libevdev library

%package -n libevdev%{sonum}
Summary:        Library for handling evdev kernel devices
Group:          System/Libraries
Suggests:       %{name}-tools

%description -n libevdev%{sonum}
Library for handling evdev kernel devices. It abstracts the ioctls
through type-safe interfaces and provides functions to change
the appearance of the device.

%package tools
Summary:        Library for handling evdev kernel devices
Group:          System/Base

%description tools
Library for handling evdev kernel devices. It abstracts the ioctls
through type-safe interfaces and provides functions to change
the appearance of the device.

Aditional utilities for libevdev library

%prep
%setup -q

%build
%configure \
  --disable-static \
  --disable-gcov
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libevdev%{sonum} -p /sbin/ldconfig
%postun -n libevdev%{sonum} -p /sbin/ldconfig

%files -n libevdev%{sonum}
%license COPYING
%{_libdir}/%{name}.so.*

%files devel
%license COPYING
%{_libdir}/%{name}.so
%{_includedir}/%{name}-1.0/
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/libevdev.*

%files tools
%license COPYING
%{_bindir}/mouse-dpi-tool
%{_bindir}/libevdev-tweak-device
%{_bindir}/touchpad-edge-detector
%{_mandir}/man1/libevdev-tweak-device.1%{?ext_man}
%{_mandir}/man1/mouse-dpi-tool.1%{?ext_man}
%{_mandir}/man1/touchpad-edge-detector.1%{?ext_man}

%changelog
* Wed Sep  4 2024 Matthias Bach <marix@marix.org>
- update to 1.13.3:
  * include: sync event codes with kernel 6.10
  * CI and build system fixes
* Tue Jun 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.13.1:
  * include: sync event codes with kernel 6.2
  * CI fixes
* Wed Aug 17 2022 Dirk Müller <dmueller@suse.com>
- update to 1.13.0:
  * include: sync event codes with kernel 5.19
  * input: use named initializers for the event struct
  * fix a few whitespace/coding style issues
  * meson and other build system fixups
* Tue Mar 29 2022 Dirk Müller <dmueller@suse.com>
- update to 1.12.1:
  * Add manpage for mouse-dpi-tool
  * include sync key codes from kernel 5.17
* Sat Dec 11 2021 Dirk Müller <dmueller@suse.com>
- update to 1.12.0:
  * doc: fix uinput device creation warnings
  * doc: fix initialization and setup error
  * gitlab CI: make the qemu selection automatic
  * gitlab CI: make the tarball distro selection automatic
  * gitlab CI: bump to Fedora 34 and Ubuntu 21.04
  * gitlab CI: update to latest ci-templates
  * include: sync event codes with kernel 5.15
  * tools: add a helper tool to list all currently known codes
  * libevdev 1.12.0
  * make-event-names: Fix determinism issue
* Fri Jun 25 2021 Matej Cepl <mcepl@suse.com>
- It is actually not necessary to use python2, python3 works as
  well.
* Tue Feb  9 2021 Dirk Müller <dmueller@suse.com>
- update to 1.11.0:
  * One new API, libevdev_disable_property()
  * Kernel 5.8 changed the SW_MAX define from 0x0f to 0x10. In some niche cases
    this causes issues if libevdev and the software build against
    different headers and thus end up with different values
  * include: sync event codes with kernel 5.10
  * Fix included license to the "always intended" MIT license
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.9.1
  * no changelog available
- remove n_buildfix_for_opensuse_12_2.patch: obsolete
* Mon Apr  6 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.0 (no changelog)
* Sun Mar 15 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.0
  * Bug fixes
  * Docs update
  * Improve tests
  * Sync with latest kernels
* Mon Dec  7 2015 jengelh@inai.de
- Update RPM groups and trivialize filelist
* Fri Nov 13 2015 mpluskal@suse.com
- Update to 1.4.5
  * Only a small fix, the suggested hwdb entry that the
  touchpad-edge-detector printed used the wrong codes for ABS_X
  and ABS_Y. Fixed with this release, the output is now suitable
  for copy/paste into the udev hwdb.
- Add gpg signature
* Fri Sep  4 2015 mpluskal@suse.com
- Update to 1.4.4
  * Fix invalid absinfo range values reported by certain mtk soc
  * tools: print out evdev override udev rule from touchpad edge
    detector
  * tools - tweak-device: add a --resolution command
  * tools - tweak-device: revamp to reduce use of globals
  * Note that libevdev_free() does not close the fd
  * tool   - tweak-device: fix wrong error message if the LED
    doesn't exist
  * tools - tweak-device: close the fd on exit
- Changes for 1.4.3
  * include: update to 4.1 header
  * tools: complain about devices that don't have abs x/y axes in
    the edge detector
  * tools: widen frequency resolution to µs in the DPI tool
- Changes for 1.4.2
  * tools: fix help string for manual DPI calculation
  * include: update to 4.0 header
- Changes for 1.4.1
  * Accept LIBEVDEV_READ_FLAG_BLOCKING as valid flag
  * ABS_MAX counts as MT axis for the event queue
  * cosmetic: fix a comment
  * Disable test-static-link in case of shared only build.
* Sat Mar 28 2015 hrvoje.senjan@gmail.com
- Update to 1.4:
  * libevdev_uinput_destroy: don't close non-open FD
  * include: update to 3.18 header
  * tools: print the formula to calculate resolutions
  * Shut up clang compiler warnings
  * tools: fix clang compiler warning
  * tools: note that the mouse frequency measured is the
    highest frequency
  * configure: rename BUILD_TESTS to ENABLE_RUNTIME_TESTS
  * test: always build the build-tests
  * tools: add a tool to change kernel devices
  * test: use -std=c89 instead of c90 for the build test
  * cosmetic: fix a couple of duplicate/missing empty lines
  * Use memcpy/memmove instead of loop operations
* Tue Feb 10 2015 hrvoje.senjan@gmail.com
- Update to 1.3.2:
  * A new tool has been added to help measure the physical
    resolution of a mouse device. This tool can (and should) be
    used to create udev hwdb entries for systemd's 70-mouse.hwdb
  * Other changes include documentation and tests fixes
- Changes since 1.3.1:
  * INPUT_PROP_POINTINGSTICK is now parsed correctly.
* Mon Sep 22 2014 hrvoje.senjan@gmail.com
- Update to 1.3:
  * m4: fix CC_CHECK_WERROR and CC_FLAG_VISIBILITY macros
  * Add per-device log handlers
  * include: update to Linux 3.15 header
  * uinput: use the UI_GET_SYSNAME ioctl if available
  * uinput: change strcpy/strcat usage for snprintf
  * include: add uinput.h header as well
  * include: update to Linux 3.16 header
  * uinput: check errno against the positive value
  * uinput: preserve the errno before cleaning up
  * configure: move the python check down to re-unite the
    gcov check outputs
  * Add libevdev_property_from_name()
  * Rename symbols leaking from static library to
    avoid name clashes
  * uinput: close the managed fd on error
  * tools: pass -rc to strerror, not rc
  * uinput: explicitly ignore the UI_DEV_DESTROY return value
  * Hook up nm to check for leaking symbols in the static library
  * Add some minimal documentation about static linking
* Sun Aug 24 2014 jengelh@inai.de
- Add git repository metadata
* Tue May 13 2014 sndirsch@suse.com
- Update to 1.2 (recommended for xf86-input-synaptics 1.8.0)
* Fri May  2 2014 coolo@suse.com
- add baselibs.conf since libevdev2-32bit is required by libinput-32bit
* Mon Mar 17 2014 hrvoje.senjan@gmail.com
- Update to 1.0.99.1 (1.1~rc1)
  * Send an extra ABS_MT_SLOT event to sync the client up with
    the current slot
  * Fix the include directives when building in tools/
  * tools: Fix compiler warning
  * Replace hardcoded 0 with the enum for it
  * tools: add a tool to print the actual range provided by
    a touchpad
  * Document that the return value of get_name|uniq|phys is
    not permanent
  * Plug a memory leak for name, uniq, phys
  * Fix memory leaks when failing to create a uinput device
  * Document the FORCE_SYNC behavior a bit better
  * Fix a wrong reference in the libevdev_next_event
    documentation
  * Add unlikely() macro
  * Don't sync past MAX_SLOTS slots
  * Dynamically allocate the slot values
  * Reduce memory requirement for MT syncing
  * Increase MAX_SLOTS to 60
  * Cap slot values to the announced maximum
  * Move some functions/macros between libevdev-int.h
    and libevdev-util.h
  * Don't sync the MT state for fake MT devices
  * If the tracking ID changes during SYN_DROPPED, terminate
    the touch first
  * Add a documentation note to update the slot after syncing
- New tools subpackage
* Wed Feb 26 2014 hrvoje.senjan@gmail.com
- Update to 1.0, for more details, please see:
  http://lists.freedesktop.org/archives/input-tools/2014-January/000763.html
  and http://lists.freedesktop.org/archives/input-tools/2014-February/000766.html
- SO version bumped to 2
- Explicitly remove la files, instead of excluding them
* Thu Feb  6 2014 sndirsch@suse.com
- fixed license to MIT in specfile
* Wed Jan  8 2014 sndirsch@suse.com
- n_buildfix_for_opensuse_12_2.patch
  * buildfix for openSUSE 12.2 (Linux kernel headers too old)
* Sun Oct 20 2013 hrvoje.senjan@gmail.com
- Initialize libevdev pckage
